{ pkgs, ... }:

let
  fontsOverlay = import (
    builtins.fetchTarball {
      url = "https://git.pompy.dev/pomp/nix-google-fonts-overlay/archive/1c39bc6d96ecfba3ba355c979e288dde1c953678.tar.gz";
      sha256 = "sha256:1cwkvynskgkpr2kzkq9gpf1haxxlw97r0rzl33vi3i1vlzyy224k";
    }
  );
in
{
  overlays = [ fontsOverlay ];

  packages = with pkgs; [
    nixd
    nixfmt-rfc-style

    # fonts
    font-awesome_6
    google-fonts-noto-serif
    google-fonts-noto-serif-kr
  ];

  scripts.compile.exec = ''
    find src/ -name '*.typ' | while read file; do
      echo "Compiling $file"
      typst compile --ignore-system-fonts --root . "$file"
    done
    echo Done!
  '';

  # https://devenv.sh/supported-languages/typst/
  languages.typst = {
    enable = true;
    fontPaths = [
      "${pkgs.font-awesome_6}/share/fonts/opentype"
      "${pkgs.google-fonts-noto-serif}/share/fonts/truetype"
      "${pkgs.google-fonts-noto-serif-kr}/share/fonts/truetype"
    ];
  };
}
