#import "../_lib/const.typ": *
#import "../_lib/cover.typ": cover
#import "@preview/fletcher:0.5.7"
#import fletcher: diagram, node, edge
#import "@preview/pinit:0.2.2": *

#set page(
  width: page_width,
  height: page_height,
  margin: page_margin,
  numbering: "1",
)
#set text(font: default_font, size: default_font_size)
#set list(marker: "•")

#cover(name: "Mathematics", slug: "math")

#set heading(numbering: "1.")
#pagebreak()

#outline()
#pagebreak()

#align(center)[= Algebra]

== Algebraic properties

#table(
  columns: (auto, 1fr, 1fr, 1fr, 1fr),
  align: (right, center, center, center, center),
  table.header([*Property*], [×], /**/ [+], /**/ [-], /**/ [÷]),
  /*********/ [Commutative / 교환법칙], [●], /**/ [●], /**/ [ ], /**/ [ ],
  /*********/ [Associative / 결합법칙], [●], /**/ [●], /**/ [ ], /**/ [ ],
  /********/ [Distributive / 분배법칙], [●], /**/ [ ], /**/ [ ], /**/ [ ],
)

#linebreak()

=== Commutative / 교환법칙

$ a+b=b+a $
$ a⋅b=b⋅a $

=== Associative / 결합법칙

$ (a+b)+c=a+(b+c) $
$ (a⋅b)⋅c=a⋅(b⋅c) $

=== Distributive / 분배법칙

$ a⋅(b+c)=a b+a c $

#pagebreak()

== Types of numbers

- $CC$ - Complex / 복소수 ($bold(a + b i)$)
  - $RR$ - Real / 실수 ($bold(a) + b i$)
    - $QQ$ - Rational / 유리수 ($p / q|p,q in ZZ,q != 0$)
    - $ZZ$ - Integer / 정수 ($..., -1, 0, 1, ...$)
      - $NN$ - Natural / 자연수 ($1, 2, 3, ...$)
      - $WW$ - Whole ($0, 1, 2, ...$)
    - Irrational / 무리수 ($pi, e, sqrt(2), ...$)
  - $II$ - Imaginary / 허수 ($a + bold(b i)$)

#align(center)[*Closed under*]
#table(
  columns: (auto, 1fr, 1fr, 1fr, 1fr, 1fr, 1fr, 1fr),
  align: (center, center, center, center, center, center, center, center),
  table.header([], [$CC$], [$RR$], [$II$], [$QQ$], [$ZZ$], [$NN$], [$WW$]),
  /***/ [$plus$], [●], [●], [●], [●], [●], [●], [●],
  /**/ [$times$], [●], [●], [●], [●], [●], [●], [●],
  /**/ [$minus$], [●], [●], [●], [●], [●], [ ], [ ],
  /****/ [$div$], [●], [●], [●], [●], [ ], [ ], [ ],
)

#pagebreak()

== Rational decimal numbers

=== Termination test
Given simplified fraction of rational number $x = p / q$, if $q = 2^m dot 5^n | m, n in ZZ$,
then decimal form of $x$ is terminating.

=== Decimal-fraction conversion
To convert a repeating decimal number to fraction, use the following formula:

#text(size: 15pt)[
  #align(center)[
    $a.#text(red)[b]#overline(stroke: black)[#text(blue)[cd]] = (a b c d-a b) / (#text(blue)[99]#text(red)[0])$
  ]
]

== Notable numbers

== $pi$ - Pi

== $e$ - Euler's number

== $phi$ - Golden ratio

#pagebreak()

== Factoring

#linebreak()

#align(center)[
  #diagram(
    node((0, 0), $(a+b)^2$),
    edge("--|>", bend: 20deg, label: "expansion / 전개"),
    edge("<|--", bend: -20deg, label: "factoring / 인수분해"),
    node((2.5, 0), $a^2 + 2 a b + b^2$),
  )
]

#linebreak()

=== Common factoring formulas

$
  (a x+b)(c x+d)/**/ &= a c x^2+(a d+b c)x+b d\
  (x+a)(x+b)/******/ &= x^2+(a+b)x+a b\
  (a x±b)^2/*******/ &= a^2±2a b x+b^2\
  (x±1 / x)^2/*****/ &= x^2±2+1 / x^2\
  a^2±b^2/*********/ &= (a±b)^2∓2a b\
  a^2-b^2/*********/ &= (a+b)(a-b)\
  a^3±b^3/*********/ &= (a±b)(a^2∓a b+b^2)\
  (a±b)^3/*********/ &= a^3±3a b(a±b)±b^3\
  /****************/ &= a^3±3a^2b+3a b^2±b^3\
$

#pagebreak()

=== Factoring quadratic equations

$
  & 2x^2-7x /*****************/ & /***********************/ + & 3 /************/ & & /**************/ \
  & #text(red)[ $2$] #pin("ul") & #pin("ur") #text(red)[ $-$] & #text(red)[ $1$] &=& #text(olive)[-1] \
  & #text(blue)[$1$] #pin("ll") & #pin("lr") #text(blue)[$-$] & #text(blue)[$3$] &=& #text(olive)[-6] \
$

#pinit-arrow("ul", "lr", start-dy: -4pt, end-dy: -4pt, thickness: 0.5pt, arrow-width: 10)
#pinit-arrow("ll", "ur", start-dy: -4pt, end-dy: -4pt, thickness: 0.5pt, arrow-width: 10)

$
  space.quad & = (#text(red)[$2x-1$])(#text(blue)[$x-3$])\
  space.quad & = 2x^2+(#text(olive)[$-6-1$])x+3
$

=== Quadratic formula

$
  /********************/ a x^2+b x+c &= 0 \
  /**************/ x^2+b / a x+c / a &= 0 \
  /********************/ x^2+b / a x &= -c / a \
  /**/ x^2+2(b / (2a))x+(b / (2a))^2 &= -c / a+(b / (2a))^2 \
  /*****************/( x+b / (2a))^2 &= (b^2-4a c) / (4a^2) \
  /*********************/ x+b / (2a) &= ±(sqrt(b^2-4a c)) / (2a) \
  /******************************/ x &= (-b ± sqrt(b^2-4a c)) / (2 a) \
$

#pagebreak()

== Logarithm

=== Exponential growth

#pagebreak()

== Conic sections

=== Point

=== Line

=== Parabola

=== Hyperbola

=== Ellipse

=== Circle

#pagebreak()

== Trigonometry

=== Trigonometric identities

#pagebreak()

== Vector

== Matrix

#pagebreak()

#align(center)[= Calculus]

== Limit

== Integral

== Series

#pagebreak()

#align(center)[= Geometry]

#pagebreak()

#align(center)[= Statistics]

== Mean, median, and mode

#pagebreak()

#align(center)[= Set theory]

#pagebreak()

#align(center)[= Miscellaneous]

== Dimension

== Fourier transform
